@@ -21,7 +21,6 @@
 #define _GNU_SOURCE 1
 #define HAVE_ALLOCA_H 1
 #define HAVE_ARPA_INET_H 1
-#define HAVE_ASM_MSR_H 1
 #define HAVE_ASM_TERMBITS_H 1
 #define HAVE_CRYPT_H 1
 #define HAVE_CURSES_H 1
@@ -43,6 +42,7 @@
 #define HAVE_LIMITS_H 1
 #define HAVE_LINK_H 1
 #define HAVE_LINUX_UNISTD_H 1
+#define HAVE_LINUX_MMAN_H 1
 #define HAVE_LOCALE_H 1
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
@@ -65,7 +65,6 @@
 #define HAVE_SYS_FILE_H 1
 /* #undef HAVE_SYS_FPU_H */
 #define HAVE_SYS_IOCTL_H 1
-#define HAVE_SYS_IPC_H 1
 /* #undef HAVE_SYS_MALLOC_H */
 #define HAVE_SYS_MMAN_H 1
 /* #undef HAVE_SYS_NDIR_H */
@@ -74,7 +73,6 @@
 #define HAVE_SYS_PRCTL_H 1
 #define HAVE_SYS_RESOURCE_H 1
 #define HAVE_SYS_SELECT_H 1
-#define HAVE_SYS_SHM_H 1
 #define HAVE_SYS_SOCKET_H 1
 /* #undef HAVE_SYS_SOCKIO_H */
 #define HAVE_SYS_UTSNAME_H 1
@@ -105,7 +103,6 @@
 /* Libraries */
 /* #undef HAVE_LIBWRAP */
 /* #undef HAVE_SYSTEMD */
-/* #undef HAVE_CRC32_VPMSUM */
 
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
@@ -121,9 +118,8 @@
 /* #undef FIONREAD_IN_SYS_FILIO */
 
 /* Functions we may want to use. */
-/* #undef HAVE_ACCEPT4 */
+#define HAVE_ACCEPT4 1
 #define HAVE_ACCESS 1
-/* #undef HAVE_AIOWAIT */
 #define HAVE_ALARM 1
 #define HAVE_ALLOCA 1
 /* #undef HAVE_BFILL */
@@ -140,7 +136,6 @@
 #define HAVE_DECL_FDATASYNC 1
 #define HAVE_FEDISABLEEXCEPT 1
 #define HAVE_FESETROUND 1
-#define HAVE_FINITE 1
 /* #undef HAVE_FP_EXCEPT */
 #define HAVE_FSEEKO 1
 #define HAVE_FSYNC 1
@@ -150,6 +145,7 @@
 #define HAVE_GETHOSTBYADDR_R 1
 /* #undef HAVE_GETHRTIME */
 #define HAVE_GETPAGESIZE 1
+/* #undef HAVE_GETPAGESIZES */
 #define HAVE_GETPASS 1
 /* #undef HAVE_GETPASSPHRASE */
 #define HAVE_GETPWNAM 1
@@ -162,38 +158,31 @@
 /* #undef gmtime_r */
 #define HAVE_IN_ADDR_T 1
 #define HAVE_INITGROUPS 1
-/* #undef HAVE_ISNAN */
-#define HAVE_LARGE_PAGE_OPTION 1
 #define HAVE_LDIV 1
 #define HAVE_LRAND48 1
 #define HAVE_LOCALTIME_R 1
-#define HAVE_LOG2 1
 #define HAVE_LSTAT 1
 #define HAVE_MEMALIGN 1
 /* #define HAVE_MLOCK 1 see Bug#54662 */
-#define HAVE_NPTL 1
 #define HAVE_NL_LANGINFO 1
 #define HAVE_MADVISE 1
 #define HAVE_DECL_MADVISE 1
 /* #undef HAVE_DECL_MHA_MAPSIZE_VA */
 #define HAVE_MALLINFO 1
 /* #undef HAVE_MALLINFO2 */
+/* #undef HAVE_MALLOC_ZONE */
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
 #define HAVE_MKSTEMP 1
+#define HAVE_MKOSTEMP 1
 #define HAVE_MLOCKALL 1
 #define HAVE_MMAP 1
 #define HAVE_MMAP64 1
 #define HAVE_PERROR 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_FALLOCATE 1
-#define HAVE_LINUX_FALLOC_H 1
 /* #undef HAVE_FALLOC_PUNCH_HOLE_AND_KEEP_SIZE */
 #define HAVE_PREAD 1
-#define HAVE_PAUSE_INSTRUCTION 1
-/* #undef HAVE_FAKE_PAUSE_INSTRUCTION */
-/* #undef HAVE_HMT_PRIORITY_INSTRUCTION */
-/* #undef HAVE_RDTSCLL */
 /* #undef HAVE_READ_REAL_TIME */
 /* #undef HAVE_PTHREAD_ATTR_CREATE */
 #define HAVE_PTHREAD_ATTR_GETGUARDSIZE 1
@@ -214,7 +203,6 @@
 #define HAVE_READLINK 1
 #define HAVE_REALPATH 1
 #define HAVE_RENAME 1
-#define HAVE_RINT 1
 /* #undef HAVE_RWLOCK_INIT */
 #define HAVE_SCHED_YIELD 1
 #define HAVE_SELECT 1
@@ -225,6 +213,7 @@
 #define HAVE_SIGACTION 1
 /* #undef HAVE_SIGTHREADMASK */
 #define HAVE_SIGWAIT 1
+#define HAVE_SIGWAITINFO 1
 #define HAVE_SLEEP 1
 #define HAVE_SNPRINTF 1
 #define HAVE_STPCPY 1
@@ -237,12 +226,11 @@
 #define HAVE_STRTOUL 1
 #define HAVE_STRTOULL 1
 /* #undef HAVE_TELL */
-#define HAVE_TEMPNAM 1
 /* #undef HAVE_THR_SETCONCURRENCY */
 /* #undef HAVE_THR_YIELD */
 #define HAVE_TIME 1
 #define HAVE_TIMES 1
-#define HAVE_VIDATTR 1
+/* #undef HAVE_VIDATTR */
 #define HAVE_VIO_READ_BUFF 1
 #define HAVE_VASPRINTF 1
 #define HAVE_VSNPRINTF 1
@@ -266,7 +254,7 @@
 #define USE_MB_IDENT 1
 
 /* this means that valgrind headers and macros are available */
-#define HAVE_VALGRIND_MEMCHECK_H 1
+/* #undef HAVE_VALGRIND_MEMCHECK_H */
 
 /* this means WITH_VALGRIND - we change some code paths for valgrind */
 /* #undef HAVE_valgrind */
@@ -385,17 +373,13 @@
 
 /* #undef HAVE_SVR3_SIGNALS */
 /* #undef HAVE_V7_SIGNALS */
-/* #undef HAVE_ERR_remove_thread_state */
+#define HAVE_ERR_remove_thread_state 1
+#define HAVE_X509_check_host 1
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
-/* #undef MY_ATOMIC_MODE_DUMMY */
-#define HAVE_GCC_ATOMIC_BUILTINS 1
-/* #undef HAVE_GCC_C11_ATOMICS */
+#define HAVE_GCC_C11_ATOMICS 1
 /* #undef HAVE_SOLARIS_ATOMIC */
-#define HAVE_DECL_SHM_HUGETLB 1
-#define HAVE_LINUX_LARGE_PAGES 1
-#define HUGETLB_USE_PROC_MEMINFO 1
 /* #undef NO_FCNTL_NONBLOCK */
 #define NO_ALARM 1
 
@@ -423,7 +407,6 @@
 /* #undef mode_t */
 /* #undef SIGQUIT */
 /* #undef SIGPIPE */
-/* #undef finite */
 /* #undef popen */
 /* #undef pclose */
 /* #undef ssize_t */
@@ -434,11 +417,11 @@
 /* #undef strtoll */
 /* #undef strtoull */
 /* #undef vsnprintf */
-#if (_MSC_VER > 1800)
+#if defined(_MSC_VER) && (_MSC_VER > 1800)
 #define tzname _tzname
 #define P_tmpdir "C:\\TEMP"
 #endif
-#if (_MSC_VER > 1310)
+#if defined(_MSC_VER) && (_MSC_VER > 1310)
 # define HAVE_SETENV
 #define setenv(a,b,c) _putenv_s(a,b)
 #endif
@@ -506,8 +489,7 @@
 #define HAVE_CHARSET_ucs2 1
 #define HAVE_CHARSET_ujis 1
 #define HAVE_CHARSET_utf8mb4 1
-/* #undef HAVE_CHARSET_utf8mb3 */
-#define HAVE_CHARSET_utf8 1
+#define HAVE_CHARSET_utf8mb3 1
 #define HAVE_CHARSET_utf16 1
 #define HAVE_CHARSET_utf32 1
 #define HAVE_UCA_COLLATIONS 1
@@ -528,7 +510,6 @@
   WITH_<ENGINE>_STORAGE_ENGINE for the whole server)
 */
 #define WITH_INNOBASE_STORAGE_ENGINE 1
-/* #undef WITH_XTRADB_STORAGE_ENGINE */
 #define WITH_PARTITION_STORAGE_ENGINE 1
 #define WITH_PERFSCHEMA_STORAGE_ENGINE 1
 #define WITH_ARIA_STORAGE_ENGINE 1
@@ -546,18 +527,19 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 2
-#define MYSQL_VERSION_PATCH 41
+#define MYSQL_VERSION_MINOR 5
+#define MYSQL_VERSION_PATCH 13
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.2.41"
+#define PACKAGE_STRING "MySQL Server 10.5.13"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.2.41"
-#define VERSION "10.2.41"
+#define PACKAGE_VERSION "10.5.13"
+#define VERSION "10.5.13"
 #define PROTOCOL_VERSION 10
+#define PCRE2_CODE_UNIT_WIDTH 8
 
 #define MALLOC_LIBRARY "system"
 
